==> starnet.1.0.tar: imain.f <==
      subroutine imain(round_aper,density,focallength,infilename,
     $     himaglim,lomaglim,magtype,outstyle,outfilename,
     $     pixelsize,ascending,sortfield,catmap,error)
C
C Description:
C
C This program is the main routine controlling the interactive mode
C of the asternet program.
C
C Note: The variable 'infilename' is not used in the program but is
C included in the interface so that this routine will be 'plug' 
C compatible with imain, the batch version.
C
C Programming interface:
C
C Name         In/out Type          Structure Meaning
C
C round_aper   in     logical       scalar    TRUE if a round aperture is
C                                             requested
C density      in     real*8        scalar    The number of stars per square
C                                             degree requested
C focallength  in     real*8        scalar    The focal length of the simulated
C                                             telescope requested for an IRAF 
C                                             star list    
C infilename   in     character*64  scalar    The name of the file containing 
C                                             the list of regions to be 
C                                             searched
C himaglim     in     real*8        scalar    The dim magnitude limit
C lomaglim     in     real*8        scalar    The bright magnitude limit
C magtype      in     character*1   scalar    The way magnitude is considered
C                                             'r' is red
C                                             'b' is blue
C                                             'd' is the difference between red
C                                             and blue
C outstyle     in     character*1   scalar    The style of the list for stars
C                                             'A' is ASCII
C                                             'I' is IRAF
C                                             'c' is catalog
C outfilename  in     character*64  scalar    The name of the file containing
C                                             the list of found stars 
C pixelsize    in     real*8        scalar    The focal length of the simulated
C                                             telescope requested for IRAF     
C                                             star list                        
C ascending    in     logical       scalar    TRUE if the found star list is
C                                             to be sorted in ASCENDING order
C                                             FALSE for decending order
C sortfield    in     character*1   scalar    Selects the parameter that
C                                             will order the found stars
C                                             'R' is RA
C                                             'D' is Decl.
C                                             'r' is red
C                                             'b' is blue
C                                             'd' is radius
C catmap       in     character*64  scalar    Name of the catalog map file
C error        in     logical       scalar    TRUE if an error has occured
C
C Errors
C
C This routine will terminate if any subroutines return with an error.
C
C Subroutines accessed:
C
C prompt_read_user
C err_msg
C find_stars
C make_ascii_list
C make_cat_list
C make_iraf_list
C
      implicit none
      include 'std_io.f'
      include 'include_astronet.f'
      real*8 density,focallength,himaglim,lomaglim,pixelsize,ra,
     $     spd,rahalf,spdhalf,radius
      logical error,round_aper,ascending,done
      integer list_length,region_count,list_ra,list_dec,list_mag
      character*64 infilename,outfilename,catmap
      character*1 magtype,outstyle,sortfield
      dimension list_ra(maxlist),list_dec(maxlist),list_mag(maxlist)
      done=.false.
      region_count=0
      do while (.not. done)
         call prompt_read_user(round_aper,ra,spd,rahalf,
     $        spdhalf,radius,error)
         if (error) goto 400
         if (round_aper) then
            if (radius .eq. 0.0d0) then
               done=.true.
            end if
         else
            if (rahalf .eq. 0.0d0) then
               done=.true.
            end if
         end if
         if (.not. done) then
            region_count=region_count+1
            if (round_aper) then
               rahalf=radius
               spdhalf=radius
            end if
            call find_stars(ra,spd,rahalf,spdhalf,
     $           lomaglim,himaglim,magtype,density,
     $           list_ra,list_dec,list_mag,list_length,catmap,error)
            if (error) goto 400
            if (outstyle .eq. 'a') then
               call make_ascii_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            elseif (outstyle .eq. 'i') then
               call make_iraf_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            elseif (outstyle .eq. 'c') then
               call make_cat_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            end if
         end if
      end do
      goto 400
 400  continue
      if (error) then
         call err_msg('imain','Traceback')
      end if
      return
      end

==> starnet.1.2.tar: imain.f <==
      subroutine imain(header,round_aper,density,
     $     focallength,infilename,bhimaglim,blomaglim,
     $     rhimaglim,rlomaglim,ihimaglim,ilomaglim,outstyle,
     $     outfilename,batch,pixelsize,ascending,sortfield,
     $     catmap,error)
C
C $Id: imain.f,v 1.3 1997/01/09 19:11:34 koehn Exp $
C
C Description:
C
C This program is the main routine controlling the interactive mode
C of the asternet program.
C
C Note: The variable 'infilename' is not used in the program but is
C included in the interface so that this routine will be 'plug' 
C compatible with imain, the batch version.
C
C Programming interface:
C
C Name         In/out Type          Structure Meaning
C
C header       in     logical       scalar    TRUE if headers are required in 
C                                             the ASCII output style
C round_aper   in     logical       scalar    TRUE if a round aperture is
C                                             requested
C density      in     real*8        scalar    The number of stars per square
C                                             degree requested
C focallength  in     real*8        scalar    The focal length of the simulated
C                                             telescope requested for an IRAF 
C                                             star list    
C infilename   in     character*64  scalar    The name of the file containing 
C                                             the list of regions to be 
C                                             searched
C bhimaglim    in     real*8        scalar    Dim blue star limit
C blomaglim    in     real*8        scalar    Bright blue star limit
C rhimaglim    in     real*8        scalar    Dim red star limit
C rlomaglim    in     real*8        scalar    Bright red star limit
C ihimaglim    in     real*8        scalar    Dim index star limit
C ilomaglim    in     real*8        scalar    Bright index star limit
C outstyle     in     character*1   scalar    The style of the list for stars
C                                             'A' is ASCII
C                                             'I' is IRAF
C                                             'c' is catalog
C outfilename  in     character*64  scalar    The name of the file containing
C                                             the list of found stars 
C batch        in     integer       scalar    1 if batch mode
C                                             0 if interactive mode
C                                             -1 if interactive mode 
C                                             with prompts
C pixelsize    in     real*8        scalar    The focal length of the simulated
C                                             telescope requested for IRAF     
C                                             star list                        
C ascending    in     logical       scalar    TRUE if the found star list is
C                                             to be sorted in ASCENDING order
C                                             FALSE for decending order
C sortfield    in     character*1   scalar    Selects the parameter that
C                                             will order the found stars
C                                             'R' is RA
C                                             'D' is Decl.
C                                             'r' is red
C                                             'b' is blue
C                                             'd' is radius
C catmap       in     character*64  scalar    Name of the catalog map file
C error        in     logical       scalar    TRUE if an error has occured
C
C Errors
C
C This routine will terminate if any subroutines return with an error.
C
C Subroutines accessed:
C
C prompt1
C prompt2
C err_msg
C find_stars
C make_ascii_list
C make_cat_list
C make_iraf_list
C
      implicit none
      include 'std_io.f'
      include 'include_starnet.f'
      real*8 density,focallength,bhimaglim,blomaglim,rhimaglim,
     $     rlomaglim,ihimaglim,ilomaglim,pixelsize,ra,
     $     spd,rahalf,spdhalf,radius
      logical error,round_aper,ascending,done,header,firsttime
      integer list_length,region_count,list_ra,list_dec,list_mag,
     $     batch
      character*64 infilename,outfilename,catmap
      character*1 outstyle,sortfield
      dimension list_ra(maxlist),list_dec(maxlist),list_mag(maxlist)
      done=.false.
      region_count=0
      firsttime=.true.
C
C Set additional default values
C
      do while (.not. done)
         if (batch .eq. 0) then
            call prompt1(round_aper,ra,spd,rahalf,
     $           spdhalf,radius,error)
            if (error) goto 400
         elseif (batch .eq. -1) then
            round_aper=.false.
            if (firsttime) then
               firsttime=.false.
               ra=0.0d0
               spd=pio2
               rahalf=pio180*300.0d0/3600.0d0
               spdhalf=pio180*300.0d0/3600.0d0
               if (outfilename .eq. ' ') then
                  outfilename='starnet.out'
               end if
               sortfield='R'
            end if
            call prompt2(header,density,
     $           focallength,infilename,bhimaglim,blomaglim,
     $           rhimaglim,rlomaglim,ihimaglim,ilomaglim,outstyle,
     $           outfilename,batch,pixelsize,ascending,sortfield,
     $           catmap,ra,spd,rahalf,spdhalf,error)
 9          if (error) goto 400
         end if
         if (round_aper) then
            if (radius .eq. 0.0d0) then
               done=.true.
            end if
         else
            if (rahalf .eq. 0.0d0) then
               done=.true.
            end if
         end if
         if (.not. done) then
            region_count=region_count+1
            if (round_aper) then
               rahalf=radius
               spdhalf=radius
            end if
            call find_stars(ra,spd,rahalf,spdhalf,
     $           rlomaglim,rhimaglim,blomaglim,bhimaglim,
     $           ilomaglim,ihimaglim,density,
     $           list_ra,list_dec,list_mag,list_length,catmap,error)
            if (error) goto 400
            if (outstyle .eq. 'a') then
               call make_ascii_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            elseif (outstyle .eq. 'i') then
               call make_iraf_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            elseif (outstyle .eq. 'c') then
               call make_cat_list(list_ra,list_dec,list_mag,
     $              list_length,spd,ra,round_aper,focallength,
     $              pixelsize,ascending,sortfield,outfilename,
     $              radius,region_count,rahalf,spdhalf,error)
               if (error) goto 400
            end if
         end if
      end do
      goto 400
 400  continue
      if (error) then
         call err_msg('imain','Traceback')
      end if
      return
      end
